@@ -1,5 +1,5 @@
 /* test-lookup.c --- Self tests for IDNA processing
-   Copyright (C) 2011 Simon Josefsson
+   Copyright (C) 2011-2013 Simon Josefsson
 
    This program is free software: you can redistribute it and/or modify
    it under the terms of the GNU General Public License as published by
@@ -690,6 +690,11 @@ static const struct idna idna[] = {
     /* Contextj: U+750 U+0300 U+200C U+0300 U+0300 U+0300 U+0750.
        U+0300 is T, U+0750 is D. */
   },
+  {
+    "\xd8\xa8\xe2\x80\x8c\xd8\xa7\xe2\x80\x8c\xd8\xa7", "", IDN2_CONTEXTJ
+    /* Contextj: U+0628 U+200C U+0627 U+200C U+0627.
+       http://article.gmane.org/gmane.ietf.idnabis/7366 */
+  },
   {
     "\xc2\xb7", "xn--uba", IDN2_OK
     /* Contexto: Lookup of U+00B7 should succeed. */
